@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.7 2004/06/04 02:25:40 daniel Exp $ */
+/* $Id: ustring.h,v 1.12.4.1 2006/02/27 21:29:48 gustin Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -232,7 +232,13 @@ public:
 
 #endif /* GLIBMM_HAVE_SUN_REVERSE_ITERATOR */
 
-  static const size_type npos = std::string::npos;
+#ifdef GLIBMM_HAVE_ALLOWS_STATIC_INLINE_NPOS
+  static GLIBMM_API const size_type npos = std::string::npos;
+#else
+  //The IRIX MipsPro compiler says "The indicated constant value is not known",
+  //so we need to initalize the static member data elsewhere.
+  static GLIBMM_API const size_type npos;
+#endif
 
   /*! Default constructor, which creates an empty string.
    */
@@ -481,9 +487,29 @@ public:
 //! @name Retrieve the string's size.
 //! @{
 
-  bool      empty()  const;
+  /** Returns true if the string is empty. Equivalent to *this == "".
+   * @result Whether the string is empty.
+   */
+  bool empty()  const;
+
+  /** Returns the number of characters in the string, not including any null-termination.
+   * @result The number of UTF-8 characters.
+   *
+   * @see bytes(), empty() 
+   */
   size_type size()   const;
+
+  //We have length() as well as size(), because std::string has both.
+
+  /** This is the same as size().
+   */
   size_type length() const;
+  
+  /** Returns the number of bytes in the string, not including any null-termination.
+   * @result The number of bytes.
+   *
+   * @see size(), empty()
+   */
   size_type bytes()  const;
 
 //! @}
@@ -578,7 +604,23 @@ private:
   template <class In, class ValueType = typename Glib::IteratorTraits<In>::value_type>
 #endif
   struct SequenceToString;
+  
+  //The Tru64 compiler needs these partial specializations to be declared here,
+  //as well as defined later. That's probably correct. murrayc.
+  template <class In>
+  struct SequenceToString<In, char>;
 
+  template <class In>
+  struct SequenceToString<In, gunichar>;
+  
+  /*
+  template <>
+  struct ustring::SequenceToString<Glib::ustring::iterator, gunichar>;
+
+  template <>
+  struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar>;
+  */
+  
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
   std::string string_;
@@ -592,25 +634,25 @@ struct ustring::SequenceToString
 {};
 
 template <class In>
-struct ustring::SequenceToString<In,char> : public std::string
+struct ustring::SequenceToString<In, char> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <class In>
-struct ustring::SequenceToString<In,gunichar> : public std::string
+struct ustring::SequenceToString<In, gunichar> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::iterator,gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::iterator, gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::iterator pbegin, Glib::ustring::iterator pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::const_iterator,gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::const_iterator pbegin, Glib::ustring::const_iterator pend);
 };
